==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/ui/visualmenu.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Ilya Kotov                                      *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <QAction>

#include <qmmp/visual.h>
#include <qmmp/visualfactory.h>

#include "pluginitem.h"
#include "visualmenu.h"

VisualMenu::VisualMenu(QWidget *parent)
 : QMenu(tr("Visualization"), parent)
{
    VisualFactory *factory = 0;
    foreach(factory, *Visual::visualFactories())
    {
        QAction *act = this->addAction(factory->properties().name);
        act->setCheckable (TRUE);
        act->setChecked (Visual::isEnabled(factory));
        VisualPluginItem *vi = new VisualPluginItem(this,factory);
        connect(act, SIGNAL(toggled(bool)), vi, SLOT(select(bool)));
    }
}

VisualMenu::~VisualMenu()
{
}

void VisualMenu::updateActions()
{
    for(int i = 0; i < Visual::visualFactories()->size(); ++i)
    {
        actions()[i]->setChecked(Visual::isEnabled(Visual::visualFactories()->at(i)));
    }
}

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/ui/visualmenu.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Ilya Kotov                                      *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <QAction>

#include <qmmp/visual.h>
#include <qmmp/visualfactory.h>

#include "pluginitem.h"
#include "visualmenu.h"

VisualMenu::VisualMenu(QWidget *parent)
 : QMenu(tr("Visualization"), parent)
{
    VisualFactory *factory = 0;
    foreach(factory, *Visual::factories())
    {
        QAction *act = this->addAction(factory->properties().name);
        act->setCheckable (TRUE);
        act->setChecked (Visual::isEnabled(factory));
        VisualPluginItem *vi = new VisualPluginItem(this,factory);
        connect(act, SIGNAL(toggled(bool)), vi, SLOT(select(bool)));
    }
}

VisualMenu::~VisualMenu()
{
}

void VisualMenu::updateActions()
{
    for(int i = 0; i < Visual::factories()->size(); ++i)
    {
        actions()[i]->setChecked(Visual::isEnabled(Visual::factories()->at(i)));
    }
}
